<?php
use PrestaShop\PrestaShop\Core\Payment\PaymentOption;
if (!defined('_PS_VERSION_')) {
    exit;
}
class Cardcom extends PaymentModule
{
    private	$_html = '';
    private $_postErrors = array();

    public function __construct()
    {
        $this->name = 'cardcom';
        $this->tab = 'payments_gateways';
        $this->version = '1.7.0.0';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->author = 'Cardcom LTD';
        $this->controllers = array('payment','validation');
        $this->currencies = true;
        $this->currencies_mode = 'radio';
        $this->bootstrap = true;
        parent::__construct();

        // $this->page = basename(__FILE__, '.php');
        $this->displayName = $this->l('CardCom');
        $this->description = $this->l('Accepts payments by CardCom');
        $this->confirmUninstall = $this->l('Are you sure you want to delete your details ?');


        if (Configuration::get('CARDCOM_USERNAME') == '')
            $this->warning = $this->l('You have to fill the Username');
        if (Configuration::get('CARDCOM_TERMINAL_NUM') == '')
            $this->warning = $this->l('You have to fill the Terminal Number');
        if (Configuration::get('CARDCOM_OPERATION') == '')
            $this->warning = $this->l('You have to fill the operation');
        if (Configuration::get('CARDCOM_INVOICE') == '')
            $this->warning = $this->l('You have to fill the invoice');
        if (Configuration::get('CARDCOM_MAX') == '')
            $this->warning = $this->l('You have to fill the max');
        if (Configuration::get('CARDCOM_LANG') == '')
            $this->warning = $this->l('You have to fill the lang');
    }

    public function install()
    {
        if (!parent::install()
            OR !Configuration::updateValue('CARDCOM_USERNAME', '')
            OR !Configuration::updateValue('CARDCOM_TERMINAL_NUM', '')
            OR !Configuration::updateValue('CARDCOM_CURRENCY', '')
            OR !Configuration::updateValue('CARDCOM_OPERATION', '')
            OR !Configuration::updateValue('CARDCOM_INVOICE', '')
            OR !Configuration::updateValue('CARDCOM_MAX', '')
            OR !Configuration::updateValue('CARDCOM_LANG', '')
            OR !$this->registerHook('paymentOptions')
            OR !$this->registerHook('paymentReturn')
        )
            return false;
        return true;
    }

    public function uninstall()
    {
        if (!Configuration::deleteByName('CARDCOM_USERNAME')
            OR !Configuration::deleteByName('CARDCOM_TERMINAL_NUM')
            OR !Configuration::deleteByName('CARDCOM_CURRENCY')
            OR !Configuration::deleteByName('CARDCOM_OPERATION')
            OR !Configuration::deleteByName('CARDCOM_INVOICE')
            OR !Configuration::deleteByName('CARDCOM_MAX')
            OR !Configuration::deleteByName('CARDCOM_LANG')
            OR !parent::uninstall())
            return false;
        return true;
    }

    public function getContent()
    {
        $this->_html = '<h2>CardCom</h2>';
        if (isset($_POST['submitCardcom']))
        {
            if (empty($_POST['cardcom_username']))
                $this->_postErrors[] = $this->l('Cardcom Username is required.');
            if (empty($_POST['cardcom_terminal_num']))
                $this->_postErrors[] = $this->l('Cardcom Terminal Number is required.');

            if (empty($_POST['cardcom_currency']))
                $this->_postErrors[] = $this->l('Cardcom Currency is required.');

            if (empty($_POST['cardcom_operation']))
                $this->_postErrors[] = $this->l('Cardcom Operation is required.');

            if ($_POST['cardcom_invoice'] != 0 &&  $_POST['cardcom_invoice'] != 1)
                $this->_postErrors[] = $this->l('Cardcom Invoice is required.');

            if (!is_numeric($_POST['cardcom_max']))
                $this->_postErrors[] = $this->l('Cardcom Max is required.');

            if (empty($_POST['cardcom_lang']))
                $this->_postErrors[] = $this->l('Cardcom Lang is required.');



            if (!sizeof($this->_postErrors))
            {
                Configuration::updateValue('CARDCOM_USERNAME', strval($_POST['cardcom_username']));
                Configuration::updateValue('CARDCOM_TERMINAL_NUM', strval($_POST['cardcom_terminal_num']));
                Configuration::updateValue('CARDCOM_CURRENCY', strval($_POST['cardcom_currency']));
                Configuration::updateValue('CARDCOM_OPERATION', strval($_POST['cardcom_operation']));
                Configuration::updateValue('CARDCOM_INVOICE', strval($_POST['cardcom_invoice']));
                Configuration::updateValue('CARDCOM_MAX', strval($_POST['cardcom_max']));
                //Configuration::updateValue('CARDCOM_IFRAME', strval($_POST['cardcom_iframe']));
                Configuration::updateValue('CARDCOM_LANG', strval($_POST['cardcom_lang']));
                $this->displayConf();
            }
            else
                $this->displayErrors();
        }

        $this->displayCardcom();
        $this->displayFormSettings();
        return $this->_html;
    }

    public function displayConf()
    {
        $this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$this->l('Settings updated').'
		</div>';
    }

    public function displayErrors()
    {
        $nbErrors = sizeof($this->_postErrors);
        $this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('There are') : $this->l('There is')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('errors') : $this->l('error')).'</h3>
			<ol>';
        foreach ($this->_postErrors AS $error)
            $this->_html .= '<li>'.$error.'</li>';
        $this->_html .= '
			</ol>
		</div>';
    }

    public function displayCardcom()
    {
        $this->_html .= '';
    }

    public function displayFormSettings()
    {

        $conf = Configuration::getMultiple(array('CARDCOM_USERNAME','CARDCOM_TERMINAL_NUM','CARDCOM_CURRENCY','CARDCOM_OPERATION','CARDCOM_INVOICE','CARDCOM_MAX','CARDCOM_IFRAME','CARDCOM_LANG'));
        $cardcom_username = array_key_exists('cardcom_username', $_POST) ? $_POST['cardcom_username'] : (array_key_exists('CARDCOM_USERNAME', $conf) ? $conf['CARDCOM_USERNAME'] : '');
        $cardcom_terminal_num = array_key_exists('cardcom_terminal_num', $_POST) ? $_POST['cardcom_terminal_num'] : (array_key_exists('CARDCOM_TERMINAL_NUM', $conf) ? $conf['CARDCOM_TERMINAL_NUM'] : '');
        $cardcom_currency = array_key_exists('cardcom_currency', $_POST) ? $_POST['cardcom_currency'] : (array_key_exists('CARDCOM_CURRENCY', $conf) ? $conf['CARDCOM_CURRENCY'] : '');

        $cardcom_operation = array_key_exists('cardcom_operation', $_POST) ? $_POST['cardcom_operation'] : (array_key_exists('CARDCOM_OPERATION', $conf) ? $conf['CARDCOM_OPERATION'] : '');

        $cardcom_invoice = array_key_exists('cardcom_invoice', $_POST) ? $_POST['cardcom_invoice'] : (array_key_exists('CARDCOM_INVOICE', $conf) ? $conf['CARDCOM_INVOICE'] : '');

        $cardcom_lang = array_key_exists('cardcom_lang', $_POST) ? $_POST['cardcom_lang'] : (array_key_exists('CARDCOM_LANG', $conf) ? $conf['CARDCOM_LANG'] : '');

        $cardcom_max = array_key_exists('cardcom_max', $_POST) ? $_POST['cardcom_max'] : (array_key_exists('CARDCOM_MAX', $conf) ? $conf['CARDCOM_MAX'] : '');

        $cardcom_iframe = array_key_exists('cardcom_iframe', $_POST) ? $_POST['cardcom_iframe'] : (array_key_exists('CARDCOM_IFRAME', $conf) ? $conf['CARDCOM_IFRAME'] : '');

        $cardcom_iframe_selected = "";
        if($cardcom_iframe == 1)
            $cardcom_iframe_selected = "selected";


        $cardcom_operation_selected = "";
        if($cardcom_operation == 4)
            $cardcom_operation_selected = "selected";


        $cardcom_invoice_selected  ="";
        if($cardcom_invoice == 1)
            $cardcom_invoice_selected = "selected";


        $this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post" style="clear: both;">
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Settings').'</legend>
			<label>'.$this->l('CardCom Username').'</label>
			<div class="margin-form"><input type="text" size="33" name="cardcom_username" value="'.htmlentities($cardcom_username, ENT_COMPAT, 'UTF-8').'" /></div>
			<label>'.$this->l('CardCom Terminal Num').'</label>
			<div class="margin-form"><input type="text" size="82" name="cardcom_terminal_num" value="'.htmlentities($cardcom_terminal_num, ENT_COMPAT, 'UTF-8').'" />
			</div>

			<label>'.$this->l('CardCom Operation').'</label>
			<div class="margin-form">
			<select name="cardcom_operation">
			<option value="1">Charge Only</option>
			<option value="4" '.$cardcom_operation_selected.' >Suspended Deal</option>
			</select>
			</div>

 			<label>'.$this->l('CardCom Invoice').'</label>
			<div class="margin-form">
			<select name="cardcom_invoice">
			<option value="0">NO</option>
			<option value="1" '.$cardcom_invoice_selected.' >YES</option>
			</select>
			</div>

			<label>'.$this->l('CardCom Currency').'</label>
			<div class="margin-form"><input type="text" size="33" name="cardcom_currency" value="'.htmlentities($cardcom_currency, ENT_COMPAT, 'UTF-8').'" /></div>


 			<label>'.$this->l('CardCom Language').'</label>
			<div class="margin-form"><input type="text" size="33" name="cardcom_lang" value="'.htmlentities($cardcom_lang, ENT_COMPAT, 'UTF-8').'" /></div>

 			<label>'.$this->l('CardCom Max').'</label>
			<div class="margin-form"><input type="text" size="33" name="cardcom_max" value="'.htmlentities($cardcom_max, ENT_COMPAT, 'UTF-8').'" /></div>


			<br /><br /><br />
			<br /><center><input type="submit" name="submitCardcom" value="'.$this->l('Update settings').'" class="button" /></center>
		</fieldset>
		</form><br /><br />
		';
    }

    public function hookPaymentReturn($params)
    {
        if (!$this->active)
            return ;

        return $this->display(__FILE__, 'confirmation.tpl');
    }

    public function hookPaymentOptions($params)
    {
        if (!$this->active) {
            return;
        }

        PrestaShopLogger::addLog("hookPaymentOptions",5);
        $newOption = new PaymentOption();
        $newOption->setModuleName($this->name);
        $newOption->setCallToActionText('תשלום בכרטיס אשראי');
        $newOption->setAction($this->context->link->getModuleLink($this->name, 'validation', array(), true))
            ->setAdditionalInformation($this->context->smarty->fetch('module:cardcom/views/templates/front/payment_infos.tpl'));

        $payments_options = [
            $newOption,
        ];
        return $payments_options;
    }

    public function getL($key)
    {
        $translations = array(
            'mc_gross' => $this->l('CardCom key \'mc_gross\' not specified, can\'t control amount paid.'),
            'payment_status' => $this->l('CardCom key \'payment_status\' not specified, can\'t control payment validity'),
            'payment' => $this->l('Payment: '),
            'cart' => $this->l('Cart not found'),
            'order' => $this->l('Order has already been placed'),
            'connect' => $this->l('Problem connecting to the CardCom server.'),
            'nomethod' => $this->l('No communications transport available.'),
            'socketmethod' => $this->l('Verification failure (using fsockopen). Returned: '),
            'curlmethod' => $this->l('Verification failure (using cURL). Returned: '),
            'curlmethodfailed' => $this->l('Connection using cURL failed'),
            'Please wait, redirecting to CardCom... Thanks.' => $this->l('Please wait, redirecting to CardCom... Thanks.'),
            'Cancel' => $this->l('Cancel'),
            'My cart' => $this->l('My cart'),
            'Return to shop' => $this->l('Return to shop'),
        );
        return $translations[$key];
    }

    function validateOrder1($id_cart, $id_order_state, $amountPaid, $paymentMethod = 'Unknown', $message = NULL, $extraVars = array(), $currency_special = NULL, $dont_touch_amount = false,$secure_key = false, Shop $shop = null)
    {
        if (!$this->active)
            return ;
        parent::validateOrder($id_cart, $id_order_state, $amountPaid, $paymentMethod, $message, $extraVars,$currency_special,$dont_touch_amount,$secure_key,$shop);
    }

}
